gedidb.L2BBeam
==============

.. currentmodule:: gedidb

.. autoclass:: L2BBeam

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~L2BBeam.__init__
      ~L2BBeam.apply_filter
      ~L2BBeam.build_virtual_dataset
      ~L2BBeam.clear
      ~L2BBeam.copy
      ~L2BBeam.create_dataset
      ~L2BBeam.create_dataset_like
      ~L2BBeam.create_group
      ~L2BBeam.create_virtual_dataset
      ~L2BBeam.get
      ~L2BBeam.items
      ~L2BBeam.keys
      ~L2BBeam.move
      ~L2BBeam.pop
      ~L2BBeam.popitem
      ~L2BBeam.require_dataset
      ~L2BBeam.require_group
      ~L2BBeam.setdefault
      ~L2BBeam.update
      ~L2BBeam.values
      ~L2BBeam.visit
      ~L2BBeam.visit_links
      ~L2BBeam.visititems
      ~L2BBeam.visititems_links
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~L2BBeam.attrs
      ~L2BBeam.beam_type
      ~L2BBeam.field_mapper
      ~L2BBeam.file
      ~L2BBeam.id
      ~L2BBeam.main_data
      ~L2BBeam.n_shots
      ~L2BBeam.name
      ~L2BBeam.parent
      ~L2BBeam.ref
      ~L2BBeam.regionref
   
   